0.14 (2021-09-09)
-----------------

- Update SDSS filter metadata to reflect that no atmospheric extinction is included.

0.13 (2021-01-18)
-----------------

- Add GAIA DR2 filter curves.

0.12 (2021-01-15)
-----------------

- Add DECam DR1 filter curves with and without X=1.2 atmosphere.

0.11 (2020-11-23)
-----------------

- Another attempt to fix broken astropy_helpers in pypi release.

0.10 (2020-11-23)
-----------------

- Fix broken 0.9 pypi release.

0.9 (2020-07-31)
----------------

- Minor updates for py3.8 support (#55)
- fix installation problems (#56)

0.8 (2018-09-11)
----------------

- Add MzLS-z, BASS-g, BASS-r filters used by DESI imaging surveys.
- Update astropy-helpers to v2.0.6.

0.7 (2017-10-03)
----------------

- Update to astropy_helpers v2.0.1 (#32).

0.6 (2017-10-02)
----------------

- Remove tests against python 3.3 and numpy 1.7.
- Add HSC filters (#31).
- Save filter curves at full machine precision (#27).
- Update to latest astropy affiliate package template.
- Add support and travis testing for python 3.6.
- Add support for band shifted filters (#20).
- Clean up package-level imports (#23).

0.5 (2016-08-22)
----------------

- Update to latest astropy affiliate package template.
- Drop support for python 2.6 and add support for python 3.5.
- Add testing against LTS release of astropy.
- Drop testing against numpy 1.6 and add numpy 1.11.
- Update readthedocs URLs (.org -> .io).
- Add LSST filter response curves.

0.4 (2016-02-17)
----------------

- Improve filter module error messages and validation.
- Add mask_invalid option to FilterSequence methods.
- Implement pad_spectrum method of FilterResponse and FilterSequence.

0.3 (2016-02-05)
----------------

- Add filter response curves and filters module.
- Add pyyaml required dependency (for reading filter curves).

0.2 (2015-11-15)
----------------

- Add downsample module.

0.1 (2015-08-05)
----------------

- Initial release.
